@@ -71,7 +71,12 @@ var namespacecom_1_1sun_1_1star_1_1drawing =
       [ "QUADRATICCURVETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a691b41c520ee6349eabbee14bdf6e3ed", null ],
       [ "UNKNOWN", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#aeecf8d431c447c75cb711133a932f0fd", null ]
     ] ],
-    [ "framework", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework" ],
+    [ "framework", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html", [
+      [ "AnchorBindingMode", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724c", [
+        [ "DIRECT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724ca1ea328a644e627283a35716a54108248", null ],
+        [ "INDIRECT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724caa70fc5026d3a310a836fa57ac51d8a4e", null ]
+      ] ]
+    ] ],
     [ "ShadingPattern", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html", [
       [ "CLEAR", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a9c8496e9c4c0490a148840cc0bdebbcb", null ],
       [ "DIAG_CROSS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ae104908eeee12239462cb41f1459ebee", null ],
@@ -143,8 +148,6 @@ var namespacecom_1_1sun_1_1star_1_1drawing =
     [ "AccessibleImageBullet", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleImageBullet.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleImageBullet" ],
     [ "AccessibleOLEShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleOLEShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleOLEShape" ],
     [ "AccessibleShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleShape" ],
-    [ "AccessibleSlideView", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleSlideView.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleSlideView" ],
-    [ "AccessibleSlideViewObject", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleSlideViewObject.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleSlideViewObject" ],
     [ "AppletShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape" ],
     [ "Background", "servicecom_1_1sun_1_1star_1_1drawing_1_1Background.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Background" ],
     [ "BarCode", "structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html", "structcom_1_1sun_1_1star_1_1drawing_1_1BarCode" ],
@@ -227,8 +230,6 @@ var namespacecom_1_1sun_1_1star_1_1drawing =
     [ "Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape" ],
     [ "ShapeCollection", "servicecom_1_1sun_1_1star_1_1drawing_1_1ShapeCollection.html", null ],
     [ "Shapes", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shapes.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shapes" ],
-    [ "SlideRenderer", "servicecom_1_1sun_1_1star_1_1drawing_1_1SlideRenderer.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1SlideRenderer" ],
-    [ "SlideSorter", "servicecom_1_1sun_1_1star_1_1drawing_1_1SlideSorter.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1SlideSorter" ],
     [ "Text", "servicecom_1_1sun_1_1star_1_1drawing_1_1Text.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Text" ],
     [ "TextProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextProperties" ],
     [ "TextShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextShape" ],
@@ -269,10 +270,8 @@ var namespacecom_1_1sun_1_1star_1_1drawing =
     [ "XShapes", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes" ],
     [ "XShapes2", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2" ],
     [ "XShapes3", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes3.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes3" ],
-    [ "XSlidePreviewCache", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache" ],
     [ "XSlidePreviewCacheListener", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCacheListener.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCacheListener" ],
-    [ "XSlideRenderer", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideRenderer.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideRenderer" ],
-    [ "XSlideSorterBase", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterBase.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterBase" ],
+    [ "XSlideSorterSelectionSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterSelectionSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterSelectionSupplier" ],
     [ "XUniversalShapeDescriptor", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XUniversalShapeDescriptor.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XUniversalShapeDescriptor" ],
     [ "CoordinateSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#a8277e08f09b131243b715893b903e0b9", null ],
     [ "CoordinateSequenceSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#ad88515aa1b0941ff1dad60f758962772", null ],
